<h1>snaplib</h1>
<h2>A simple data preprocessing tools.</h2>

____________________________________________

# user guide

**[Kaggle Notebook](https://www.kaggle.com/code/artyomkolas/data-preprocessing-lib?scriptVersionId=116077080)**   
<https://www.kaggle.com/code/artyomkolas/data-preprocessing-lib?scriptVersionId=116077080>
